@@ -6,8 +6,8 @@ public:
     deadcall(const char *id, const char * reason);
     ~deadcall();
 
-    virtual bool process_incoming(char * msg, struct sockaddr_storage *);
-    virtual bool  process_twinSippCom(char * msg);
+    virtual bool process_incoming(const char* msg, const struct sockaddr_storage *);
+    virtual bool process_twinSippCom(char* msg);
 
     virtual bool run();
 
