@@ -45,7 +45,7 @@ extern "C" {
     int check(uint16_t*, int);
     uint16_t checksum_carry(int);
     int prepare_pkts(const char*, pcap_pkts*);
-    int prepare_dtmf(const char*, pcap_pkts*, uint16_t start_seq_no);
+    int prepare_dtmf(char*, pcap_pkts*, uint16_t start_seq_no);
 #ifdef __cplusplus
 }
 #endif
